| Title: | Quantile Least Mahalanobis Distance Estimator for Tukey g-&-h Mixture |
|---|---|
| Description: | Functions for simulation, estimation, and model selection of finite mixtures of Tukey g-and-h distributions. The author has retired from academic research. Accordingly, this package should not be considered a validated tool for use in peer-reviewed publications or as the basis for grant applications. Backward compatibility with user-code published in <doi:10.1007/s11222-025-10596-9> is not maintained in versions >= 0.3.0 (July 2026) of this package. The authors of those publications are the appropriate contacts for reproducibility inquiries. |
| Authors: | Tingting Zhan [aut, cre] (ORCID: <https://orcid.org/0000-0001-9971-4844>) |
| Maintainer: | Tingting Zhan <[email protected]> |
| License: | GPL-2 |
| Version: | 0.3.0 |
| Built: | 2026-07-23 10:33:38 UTC |
| Source: | https://github.com/cran/QuantileGH |
Functions for simulation, estimation, and model selection of finite mixtures of Tukey g-and-h distributions. The author has retired from academic research. Accordingly, this package should not be considered a validated tool for use in peer-reviewed publications or as the basis for grant applications. Backward compatibility with user-code published in doi:10.1007/s11222-025-10596-9 is not maintained in versions >= 0.3.0 (July 2026) of this package. The authors of those publications are the appropriate contacts for reproducibility inquiries.
Tools for simulating and fitting finite mixtures of the 4-parameter Tukey -&- distributions.
Tukey -&- mixture is highly flexible to model multimodal distributions with variable degree of skewness and kurtosis in the components.
The Quantile Least Mahalanobis Distance estimator (QLMDe) is used for estimating parameters of the finite Tukey -&- mixtures.
QLMDe is an indirect estimator that minimizes the Mahalanobis distance between the sample and model-based quantiles.
A backward-forward stepwise model selection algorithm is provided to find
a parsimonious Tukey -&- mixture model, conditional on a given number-of-components; and
the optimal number of components within the user-specified range.
This R package author has retired from academic research.
Accordingly, this package should not be considered a validated tool for use in peer-reviewed publications or as the basis for grant applications.
Backward compatibility with user-code published in the following publications is not maintained in versions >= 0.3.0 of this package. The authors of those publications are the appropriate contacts for reproducibility inquiries.
doi:10.1007/s11222-025-10596-9
Maintainer: Tingting Zhan [email protected] (ORCID)
Authors:
Tingting Zhan [email protected] (ORCID)